"""
cBioPortal_get_gene_panels

Get all gene panels used in cBioPortal studies. Gene panels define which genes were sequenced in ...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def cBioPortal_get_gene_panels(
    page_size: Optional[int] = 50,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> list[Any]:
    """
    Get all gene panels used in cBioPortal studies. Gene panels define which genes were sequenced in ...

    Parameters
    ----------
    page_size : int
        Number of panels to return
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    list[Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {k: v for k, v in {"page_size": page_size}.items() if v is not None}
    return get_shared_client().run_one_function(
        {
            "name": "cBioPortal_get_gene_panels",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["cBioPortal_get_gene_panels"]
