"""
Rhea_search_by_chebi

Search for biochemical reactions involving a specific ChEBI compound in Rhea. Returns reactions w...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def Rhea_search_by_chebi(
    chebi_id: str,
    limit: Optional[int | Any] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search for biochemical reactions involving a specific ChEBI compound in Rhea. Returns reactions w...

    Parameters
    ----------
    chebi_id : str
        ChEBI compound identifier. Can include or omit 'CHEBI:' prefix. Examples: 'CH...
    limit : int | Any
        Maximum number of results (default 20, max 50).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v for k, v in {"chebi_id": chebi_id, "limit": limit}.items() if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "Rhea_search_by_chebi",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["Rhea_search_by_chebi"]
